summaryrefslogtreecommitdiffstats
path: root/dcop/dcopobject.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
commit10308be19ef7fa44699562cc75946e7ea1fdf6b9 (patch)
tree4bc444c00a79e88105f2cfce5b6209994c413ca0 /dcop/dcopobject.h
parent307136d8eef0ba133b78ceee8e901138d4c996a1 (diff)
downloadtdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.tar.gz
tdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1212479 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'dcop/dcopobject.h')
-rw-r--r--dcop/dcopobject.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/dcop/dcopobject.h b/dcop/dcopobject.h
index d1f19ccb4..2040379b2 100644
--- a/dcop/dcopobject.h
+++ b/dcop/dcopobject.h
@@ -299,16 +299,16 @@ public:
static bool hasObject(const TQCString &objId);
/**
* Try to tqfind a dcop object with the given id.
* This function does not query the DCOPObjectProxy.
* @param objId the object id to search
* @return the DCOPObject for the id @p objId.
*/
- static DCOPObject *tqfind(const TQCString &objId);
+ static DCOPObject *find(const TQCString &objId);
/**
* Tries to tqfind an object using a partial object id.
* This function is used for multicasting a DCOP message to
* several objects inside a single process.
*
@@ -299,16 +299,16 @@ public:
static bool hasObject(const TQCString &objId);
/**
- * Try to tqfind a dcop object with the given id.
+ * Try to find a dcop object with the given id.
* This function does not query the DCOPObjectProxy.
* @param objId the object id to search
@@ -299,16 +299,16 @@ public:
/**
- * Tries to tqfind an object using a partial object id.
+ * Tries to find an object using a partial object id.
* This function is used for multicasting a DCOP message to
* several objects inside a single process.